@@ -56,6 +56,24 @@ private Q_SLOTS:
         QStringList nameFilterList = QStringList() << QStringLiteral("c (*.cpp)") << QStringLiteral("h (*.h)");
         dialog.setNameFilters(nameFilterList);
         QCOMPARE(dialog.nameFilters(), nameFilterList);
+
+        dialog.show();
+        KFileWidget *fw = findFileWidget();
+        QVERIFY(fw);
+        QCOMPARE(fw->currentFilter(), QStringLiteral("*.cpp"));
+    }
+
+    void testSetNameFilterNoParenthesis()
+    {
+        QFileDialog dialog;
+
+        QStringList nameFilterList = QStringList() << QStringLiteral("*.cpp") << QStringLiteral("*.h");
+        dialog.setNameFilters(nameFilterList);
+        QCOMPARE(dialog.nameFilters(), nameFilterList);
+        dialog.show();
+        KFileWidget *fw = findFileWidget();
+        QVERIFY(fw);
+        QCOMPARE(fw->currentFilter(), QStringLiteral("*.cpp"));
     }
 
     void testSelectNameFilter()
@@ -104,13 +122,23 @@ private Q_SLOTS:
 
         QFETCH(QStringList, mimeTypeFilters);
         dialog.setMimeTypeFilters(mimeTypeFilters);
-        dialog.show();
 
         QFETCH(QString, targetMimeTypeFilter);
         dialog.selectMimeTypeFilter(targetMimeTypeFilter);
 
+        dialog.show();
         QCOMPARE(dialog.selectedMimeTypeFilter(), targetMimeTypeFilter);
     }
+
+    void testFallbackOnFirstFilterInSaveMode()
+    {
+        QFileDialog dialog;
+        dialog.setAcceptMode(QFileDialog::AcceptSave);
+        dialog.setMimeTypeFilters({QStringLiteral("application/json"), QStringLiteral("application/zip")});
+        dialog.show();
+        QCOMPARE(dialog.selectedMimeTypeFilter(), QStringLiteral("application/json"));
+    }
+
 #endif
 
 
